@@ -11,12 +11,6 @@ from textwrap import wrap
 import yaml
 
 import typing
-from enum import IntFlag
-
-
-class ECODE(IntFlag):
-    SUCCESS = 0
-    BAD = 1
 
 
 class Text(str):
@@ -361,6 +355,13 @@ class File:
             cls.message = Text(ex)
             return False
 
+    @classmethod
+    def change_new_name(cls, filename, replaced='/<HOME_DIR>'):
+        """change file to new name"""
+        home_dir = str(Path.home())
+        new_name = filename.replace(home_dir, replaced)
+        return new_name
+
 
 class Misc:
 
@@ -393,7 +394,7 @@ class Misc:
         Parameters
         ----------
         obj (object): a number or text number.
-        referred_return_type (int, float, bool): a referred return type.
+        return_type (int, float, bool): a referred return type.
 
         Returns
         -------
@@ -405,7 +406,7 @@ class Misc:
             data = obj.strip()
             try:
                 if data.lower() == 'true' or data.lower() == 'false':
-                    result = bool(data)
+                    result = True if data.lower() == 'true' else False
                 else:
                     result = float(data) if '.' in data else int(data)
 
@@ -476,6 +477,14 @@ class Misc:
         sep = kwargs.get('sep', sep)
         return sep.join(str(item) for item in args)
 
+    @classmethod
+    def skip_first_line(cls, data):
+        if not cls.is_string(data):
+            return data
+        else:
+            new_data = '\n'.join(data.splitlines()[1:])
+            return new_data
+
 
 class DictObject(dict):
     def __init__(self, *args, **kwargs):
@@ -488,17 +497,27 @@ class DictObject(dict):
 
     def __setitem__(self, key, value):
         super().__setitem__(key, value)
-        self.update(**{key: value})
+        self.update({key: value})
 
     def update(self, *args, is_updated_attr=True, **kwargs):
         obj = dict(*args, **kwargs)
-        super().update(**obj)
+        super().update(obj)
         if is_updated_attr:
             for attr, value in obj.items():
-                if re.match(r'(?i)[a-z]\w*$', attr):
+                if Misc.is_string(attr) and re.match(r'(?i)[a-z]\w*$', attr):
                     setattr(self, attr, value)
 
 
+class DotObject(DictObject):
+    def __getattribute__(self, attr):
+        value = super().__getattribute__(attr)
+        return DotObject(value) if Misc.is_dict(value) else value
+
+    def __getitem__(self, key):
+        value = super().__getitem__(key)
+        return DotObject(value) if Misc.is_dict(value) else value
+
+
 class MiscDevice:
     @classmethod
     def parse_host(cls, data):
